.. Koalak documentation master file, created by
   sphinx-quickstart on Wed Oct 16 09:49:09 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

Koalak
######
Koalak is a library that will helps you create your libraries. It was mainly
designed to handle plugins architectures. These are the main Koalak features:

**Features**

- Handle plugins architectures
   - Easy plugin addition by inheriting from a base class
   - Adding plugins through home path
   - Adding constraints on plugins class



.. toctree::
    :maxdepth: 2
    :caption: User's Guide

    quickstart
